/* Hurd version
   Copyright (C) 1996, 1997 Free Software Foundation, Inc.
   Written by Thomas Bushnell, n/BSG.

   This file is part of the GNU Hurd.

   The GNU Hurd is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2, or (at
   your option) any later version.

   The GNU Hurd is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA. */

/* See sh-version.sed for duplicates of this information. */

#ifndef HURD_VERSION
#define HURD_VERSION "0.2"
#endif

/* The standard way to print versions for --version.  */
#define _SHV_SEP "; "
#define STANDARD_HURD_VERSION(s, extra...) \
  #s " (GNU Hurd" _SHV_SEP ##extra ") " HURD_VERSION

   
